#!/bin/sh
echo 'name: murmur-hash
version: 0.1.0.6
id: murmur-hash-0.1.0.6-4ff91c2fc4da0b0998da1054b92f39ed

license: BSD3
copyright:
maintainer: Thomas Schilling <nominolo@googlemail.com>
stability: provisional
homepage: http://github.com/nominolo/murmur-hash
package-url:
synopsis: MurmurHash2 implementation for Haskell.
description: Implements MurmurHash2, a good, fast, general-purpose,
             non-cryptographic hashing function.  See
             <http://murmurhash.googlepages.com/> for details.
             .
             This implementation is pure Haskell, so it might be a bit slower
             than a C FFI binding.
category: Data, Digest
author: Thomas Schilling
pkgpath: devel/hs-murmur-hash
exposed: True
exposed-modules: Data.Digest.Murmur32 Data.Digest.Murmur64
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc/murmur-hash-0.1.0.6
library-dirs: /usr/local/lib/ghc/murmur-hash-0.1.0.6
hs-libraries: HSmurmur-hash-0.1.0.6
extra-libraries:
extra-ghci-libraries:
include-dirs:
includes:
depends: base-4.6.0.1-d435272bc8de1d17f3a0aacfbd562dbe
         bytestring-0.10.0.2-f858e0cb19bca2e9549882fc8424f656
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/hs-murmur-hash-0.1.0.6/html/murmur-hash.haddock
haddock-html: /usr/local/share/doc/hs-murmur-hash-0.1.0.6/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
